# File Organizer

A simple tool to organize files in directories based on their extensions.

## Installation

You can install the package via pip:

## Usage

To organize files in a specific directory:

